-- Paquetage complet de gestion du type Character
-- Fichier p_carac.ads 
-- Ecrit par P. SEBILO le 20.5.98
-- Dernire mise a jour le 11.10.2001 

--   Les caractres sont de code 'LATIN_1' (Paquetage Handling)
--   Les caractres accentus sont accepts

with Ada.Characters.Handling;

package P_Carac is

   ------------------ Renames paquetage Handling ------------------
   ----------------------------------------------------------------

   function Est_Carac_Iso646 (
         C : in     Character ) 
     return Boolean renames Ada.Characters.Handling.Is_Iso_646; 
   -- Fonction vraie si le caractere fait partie des 128 premiers
   --   elements du  code LATIN1 (Ancien code ASCII)

   function Est_Carac_Controle (
         C : in     Character ) 
     return Boolean renames Ada.Characters.Handling.Is_Control; 
   -- Fonction vraie si le caractere est non editable 
   --   range 0..31 et 127..159

   function Est_Carac_Editable (
         C : in     Character ) 
     return Boolean renames Ada.Characters.Handling.Is_Graphic; 
   -- Fonction vraie si le caractere est editable 
   --   (autre qu'un caractere de controle)

   function Est_Carac_Majuscule (
         C : in     Character ) 
     return Boolean renames Ada.Characters.Handling.Is_Upper; 
   -- Fonction vraie si le caractere est une lettre majuscule

   function Est_Carac_Minuscule (
         C : in     Character ) 
     return Boolean renames Ada.Characters.Handling.Is_Lower; 
   -- Fonction vraie si le caractere est une lettre minuscule

   function Est_Carac_Alpha (
         C : in     Character ) 
     return Boolean renames Ada.Characters.Handling.Is_Letter; 
   -- Fonction vraie si le caractere est une lettre

   function Est_Carac_Numerique (
         C : in     Character ) 
     return Boolean renames Ada.Characters.Handling.Is_Digit; 
   -- Fonction vraie si le caractere est un chiffre (base 10)

   function Est_Carac_Hexa (
         C : in     Character ) 
     return Boolean renames Ada.Characters.Handling.Is_Hexadecimal_Digit; 
   -- Fonction vraie si le caractere est un chiffre (base 16)
   -- caracteres '0'..'9' et 'A'..'F' et 'a'..'f'

   function Est_Carac_Alphanum (
         C : in     Character ) 
     return Boolean renames Ada.Characters.Handling.Is_Alphanumeric; 
   -- Fonction vraie si le caractere est une lettre ou un chiffre 

   ---------------------- Gestion de l'espace ---------------------
   ----------------------------------------------------------------

   function Est_Carac_Espace (
         C : in     Character ) 
     return Boolean; 
   -- Fonction vraie si le caractere est un espace

   function Est_Carac_Alpha_Espace (
         C : in     Character ) 
     return Boolean; 
   -- Fonction vraie si le caractere est une lettre ou un espace

   function Est_Carac_Alphanum_Espace (
         C : in     Character ) 
     return Boolean; 
   -- Fonction vraie si le caractere est alphanumerique ou espace

   ----------------------- Autres fonctions -----------------------
   ----------------------------------------------------------------

   function Est_Carac_Operateur (
         C : in     Character ) 
     return Boolean; 
   -- Fonction vraie si '+', '-', '*', '/'

   function Est_Carac_Signe (
         C : in     Character ) 
     return Boolean; 
   -- Fonction vraie si '+', '-'

   function Est_Carac_Operateur_Unaire (
         C : in     Character ) 
     return Boolean renames Est_Carac_Signe; 

   function Est_Carac_Binaire (
         C : in     Character ) 
     return Boolean; 
   -- Fonction vraie si C='0' ou C='1'

   function Est_Carac_Separateur (
         C : in     Character ) 
     return Boolean; 
   -- Fonction vraie si C est un des caracteres :
   --          , ; . : / * - _ espace

   ------------------------ Transformations -----------------------
   ----------------------------------------------------------------

   procedure Trans_Carac_Majuscule (
         C : in out Character ); 
   -- Transforme C en majuscule si possible

   procedure Trans_Carac_Minuscule (
         C : in out Character ); 
   -- Transforme C en minuscule si possible

   function Carac_Majuscule (
         C : in     Character ) 
     return Character renames Ada.Characters.Handling.To_Upper; 
   -- Transforme C en majuscule si possible

   function Carac_Minuscule (
         C : in     Character ) 
     return Character renames Ada.Characters.Handling.To_Lower; 
   -- Transforme C en minuscule si possible

end P_Carac;
