-- Paquetage de gestion d'un type ENTIER personnel 
-- Fichier p_entier.ads 
-- Ecrit par P. SEBILO le 29.3.96
-- Dernire mise  jour le 15.10.2002 

-- Le type ENTIER est distinct du type INTEGER.
-- Ce type est indpendant de l'implmentation.
--    => On vite ainsi les problmes de portabilit.

package P_Entier is

   Limite : constant := + 1_000_000;  

   type T_Entier is range - Limite .. + Limite; 

   -- On gnralisera plus tard le type T_ENTIER 
   --   en rendant le paquetage 'GENERIQUE'.

   subtype T_Naturel is T_Entier range 0..Limite;
   subtype T_Positif is T_Entier range 1..Limite;

   procedure Lire (
         L_Invite : in     String;  
         L_Entier :    out T_Entier ); 
   -- Lecture controle d'un Entier

   procedure Lire (
         L_Invite  : in     String;   
         L_Entier  :    out T_Entier; 
         Borne_Inf,                   
         Borne_Sup : in     T_Entier  ); 
   -- Lecture controle d'un Entier born

   procedure Ecrire (
         L_Entier : in     T_Entier ); 

   function Est_Naturel (
         A : in     T_Entier ) 
     return Boolean; 
   function Est_Positif (
         A : in     T_Entier ) 
     return Boolean; 

   function Est_Pair (
         A : in     T_Entier ) 
     return Boolean; 
   function Est_Impair (
         A : in     T_Entier ) 
     return Boolean; 

   function Maximum (
         A,                  
         B : in     T_Entier ) 
     return T_Entier renames T_Entier'Max (
         A, 
         B  ); 
   -- Renvoie le maximum de A, B

   function Minimum (
         A,                  
         B : in     T_Entier ) 
     return T_Entier renames T_Entier'Min (
         A, 
         B  ); 
   -- Renvoie le minimum de A, B

   procedure Echanger (
         A,                  
         B : in out T_Entier ); 

   procedure Trier (
         A,                      
         B    : in     T_Entier; 
         Maxi,                   
         Mini :    out T_Entier  ); 
   -- Tri de 2 valeurs

   procedure Trier (
         A,                        
         B,                        
         C      : in     T_Entier; 
         Maxi,                     
         Median,                   
         Mini   :    out T_Entier  ); 
   -- Tri de 3 valeurs

end P_Entier;
