-- Paquetage P_VECTEUR
-- Fichier p_vecteur.ads 
-- Auteur: P. SEBILO
-- Date: 25.4.96
-- Derniere mise a jour : 15.10.2002 

with P_Entier, P_Indice;
use P_Entier, P_Indice;

package P_Vecteur is

   type T_Vecteur is array (T_Indice) of T_Entier; 

   -- Remarques : 
   --    Tous les vecteurs ont la meme contrainte d'indice.
   --    On suppose qu'il y a au moins 2 lments dans le vecteur :
   --       Les vecteurs vides ne sont pas controles 
   --       (pas de traitement d'exception pour le moment);

   ------------------------------ LIRE/ECRIRE  ------------------------------ 

   -- Pour chaque operation LIRE/ECRIRE, la valeur est prcede de l'invite 
   -- constitue de l'identificateur du vecteur et de l'indice de l'lment.
   -- Exemple : VEC1(6) : 341

   procedure Lire (
         Identificateur : in     String    := ""; 
         V              :    out T_Vecteur        ); 
   procedure Ecrire (
         Identificateur : in     String    := ""; 
         V              : in     T_Vecteur        ); 

   ----------------------- Gestion a partir du RANG ------------------------- 

   function Get (
         V : in     T_Vecteur; 
         R : in     T_Rang     ) 
     return T_Entier; 
   -- Accesseur : Accs  l'lment de rang R.

   procedure Set (
         V : in out T_Vecteur; 
         R : in     T_Rang;    
         E : in     T_Entier   ); 
   -- Modifieur : Mise en place de E au rang R.

   -------------------------------- Calculs ---------------------------------

   function "+" (
         V1,                   
         V2 : in     T_Vecteur ) 
     return T_Vecteur; 
   -- Somme des deux vecteurs element par element.

   function "-" (
         V : in     T_Vecteur ) 
     return T_Vecteur; 
   -- Changement de signe des elements.

   function "-" (
         V1,                   
         V2 : in     T_Vecteur ) 
     return T_Vecteur; 
   -- Difference des deux vecteurs element par element.

   function "*" (
         V1,                   
         V2 : in     T_Vecteur ) 
     return T_Vecteur; 
   -- Multiplication des deux vecteurs element par element.

   function "*" (
         V1,                   
         V2 : in     T_Vecteur ) 
     return T_Entier; 
   -- Produit scalaire des deux vecteurs.

   function Somme (
         V : in     T_Vecteur ) 
     return T_Entier; 
   -- Somme des elements du vecteur.

   function Moyenne (
         V : in     T_Vecteur ) 
     return T_Entier; 
   function Moyenne (
         V : in     T_Vecteur ) 
     return Float; 

   -------------------------------- Divers ----------------------------------

   function Minimum (
         V : in     T_Vecteur ) 
     return T_Entier; 
   function Maximum (
         V : in     T_Vecteur ) 
     return T_Entier; 
   -- Calcul du maximum / minimum des lments du vecteur.

end P_Vecteur;
